@@ -46,13 +46,6 @@ class DiffDirException(Exception):
     pass
 
 
-def DirSig(path_iter):
-    """
-    Alias for SigTarBlockIter below
-    """
-    return SigTarBlockIter(path_iter)
-
-
 def DirFull(path_iter):
     """
     Return a tarblock full backup of items in path_iter
@@ -111,7 +104,7 @@ def get_delta_path(new_path, sig_path, sigTarFile=None):
     Return new delta_path which, when read, writes sig to sig_fileobj,
     if sigTarFile is not None
     """
-    assert new_path
+    assert new_path, "new_path must not be None or falsy when computing delta"
     if sigTarFile:
         ti = new_path.get_tarinfo()
         index = new_path.index
@@ -502,7 +495,7 @@ class TarBlockIter(object):
         """
         Turn next value of input_iter into a TarBlock
         """
-        assert not self.process_waiting
+        assert not self.process_waiting, "process_waiting should be False before starting a new process"
         raise NotImplementedError("'process' not implemented.")
 
     def process_continued(self):
@@ -512,7 +505,7 @@ class TarBlockIter(object):
         If processing val above would produce more than one TarBlock,
         get the rest of them by calling process_continue.
         """
-        assert self.process_waiting
+        assert self.process_waiting, "process_continued called without a waiting process to continue"
         raise NotImplementedError("'process_continues' not implemented.")
 
     def __next__(self):
@@ -610,36 +603,12 @@ class DummyBlockIter(TarBlockIter):
         return self.tarinfo2tarblock(index, ti)
 
 
-class SigTarBlockIter(TarBlockIter):
-    """
-    TarBlockIter that yields blocks of a signature tar from path_iter
-    """
-
-    def process(self, path):
-        """
-        Return associated signature TarBlock from path
-        """
-        ti = path.get_tarinfo()
-        if path.isreg():
-            sfp = librsync.SigFile(path.open("rb"), get_block_size(path.getsize()))
-            sigbuf = sfp.read()
-            sfp.close()
-            ti.name = b"signature/" + b"/".join(path.index)
-            ti.name = os.fsdecode(ti.name)
-            return self.tarinfo2tarblock(path.index, ti, sigbuf)
-        else:
-            ti.name = b"snapshot/" + b"/".join(path.index)
-            ti.name = os.fsdecode(ti.name)
-            return self.tarinfo2tarblock(path.index, ti)
-
-
 class DeltaTarBlockIter(TarBlockIter):
     """
     TarBlockIter that yields parts of a deltatar file
 
-    Unlike SigTarBlockIter, the argument to __init__ is a
-    delta_path_iter, so the delta information has already been
-    calculated.
+    The argument to __init__ is a delta_path_iter, so the delta information
+    must be calculated by the caller.
     """
 
     def process(self, delta_ropath):
@@ -662,7 +631,7 @@ class DeltaTarBlockIter(TarBlockIter):
             if not delta_ropath.type:
                 add_prefix(ti, r"deleted")
             else:
-                assert delta_ropath.difftype == "snapshot"
+                assert delta_ropath.difftype == "snapshot", "Expected snapshot difftype for fileless delta_ropath"
                 add_prefix(ti, r"snapshot")
             return self.tarinfo2tarblock(index, ti)
 
@@ -707,7 +676,7 @@ class DeltaTarBlockIter(TarBlockIter):
         """
         Return next volume in multivol diff or snapshot
         """
-        assert self.process_waiting
+        assert self.process_waiting, "No multivolume process is waiting; cannot continue"
         ropath = self.process_ropath
         ti, index = ropath.get_tarinfo(), ropath.index
         ti.name = f"{self.process_prefix}/{int(self.process_next_vol_number)}"
@@ -738,7 +707,7 @@ def write_block_iter(block_iter, out_obj):
     for block in block_iter:
         fp.write(block.data)
     fp.write(block_iter.get_footer())
-    assert not fp.close()
+    assert not fp.close(), "fp failed to close"
     if isinstance(out_obj, Path):
         out_obj.setdata()
 
